@@ -82,8 +82,8 @@ pairslapmeg<-function(fixed, random, grouping, subject, data){
 
   ##preliminary checks for formula and elements
   if(missing(fixed)) stop('The argument Fixed must be specified for all models!')
-  if(class(fixed)!="formula") stop("The argument Fixed must be a formula!")
-  if (length(fixed[[2]])<2) stop('Pathway must include more than one feature!')
+  if(!inherits(fixed, "formula")) stop("The argument Fixed must be a formula!")
+  if(length(fixed[[2]])<2) stop('Pathway must include more than one feature!')
 
   if(random==~-1) stop("At least a random intercept is required!")
   if(missing(random)) stop("At least a random intercept is required!")
